/*
 * location-module
 *
 * Copyright (c) 2010-2013 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Contact: Youngae Kang <youngae.kang@samsung.com>, Minjune Kim <sena06.kim@samsung.com>
 *          Genie Kim <daejins.kim@samsung.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

//http://www.yournavigation.org/api/1.0/gosmore.php?format=geojson&flat=52.215676&flon=5.963946&tlat=52.2573&tlon=6.1799&v=motorcar&fast=1&layer=mapnik
//http://www.yournavigation.org/api/1.0/gosmore.php?formats=geojson/&flat=52.215676&flot=5.963946&tlat=52.257300&tlon=6.179900&v=carmotor&fast=1&instructions=1&layer=mapnik
//http://www.yournavigation.org/api/1.0/gosmore.php?format=geojson&flat=52.215676&flon=5.963946&tlat=52.2573&tlon=6.179900&v=motorcar&fast=1&instructions=1&layer=mapnik

#include <location.h>
#include <string.h>
#include <stdio.h>
#include "log.h"

const char *YOURS_SERVER = "http://www.yournavigation.org/api/1.0/gosmore.php?";
const char *YOURS_FORMAT = "format=";
const char *YOURS_INSTRUCTIONS = "instructions=";
const char *YOURS_TYPE = "v=";
const char *YOURS_FAST = "fast=";
const char *YOURS_END = "layer=mapnik";

const char *YOURS_FORMAT_KML = "kml";
const char *YOURS_FORMAT_GEOJSON = "geojson";

const char *YOURS_SET_ON = "1";
const char *YOURS_SET_OFF = "0";

const char delimeter = '&';

static int _add_option (char *buf, const char *key, const char *option)
{
	if (!buf || !option) return -1;

	if (strlen(buf) == 0) {	//create
		strncpy(buf, YOURS_SERVER, strlen (YOURS_SERVER));

		if (key) strncat(buf, key, strlen (key));
		strncat(buf, option, strlen (option));

	} else {
		strncat(buf, &delimeter, 1);
		if (key) strncat(buf, key, strlen (key));
		strncat(buf, option, strlen (option));
	}

	return 0;
}

char* yournavi_create_url (gdouble flat, gdouble flon, gdouble tlat, gdouble tlon, GList *way, int type, char *mode ,int instruction)
{
	char url[1024] = {0, };
	char pos_str[64] = {0, };

	//TODO WAYPOINT : Not supported


#if 0	// kml
	_add_option(url, YOURS_FORMAT, YOURS_FORMAT_KML);
#else
	_add_option(url, YOURS_FORMAT, YOURS_FORMAT_GEOJSON);
#endif

	snprintf(pos_str, 64, "flat=%f&flot=%f&tlat=%f&tlon=%f", flat, flon, tlat, tlon);
	_add_option (url, NULL, pos_str);

	_add_option (url, YOURS_TYPE, mode);

	if (type)
		_add_option (url, YOURS_FAST, YOURS_SET_ON);
	else
		_add_option (url, YOURS_FAST, YOURS_SET_OFF);

	if (instruction)
		_add_option (url, YOURS_INSTRUCTIONS, YOURS_SET_ON);

	_add_option (url, NULL, YOURS_END);

	MOD_LOGW ("URL[%s]", url);

	return g_strdup(url);
}

